==> order-center-infrastructure-3.0.0-CLOUD-DEV-20220816.101450-33-sources.jar: com/tydic/dyc/oc/repository/po/UocShipOrderItemPo.java <==
package com.tydic.dyc.oc.repository.po;

import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 标题:UocShipOrderItemPo
 * 说明:发货明细
 * 时间:2022-05-13 13:45
 * 作者:罗有
 **/
@Data
public class UocShipOrderItemPo implements Serializable {
	private static final long serialVersionUID = -5105669703283919805L;

	@DocField(value = "发货明细id")
	private Long shipOrderItemId;

	@DocField(value = "订单id")
	private Long orderId;

	@DocField(value = "销售单id")
	private Long saleOrderId;

	@DocField(value = "销售明细id")
	private Long saleOrderItemId;

	@DocField(value = "发货单id")
	private Long shipOrderId;

	@DocField(value = "明细状态")
	private String shipItemState;

	@DocField(value = "计量单位")
	private String unitName;

	@DocField(value = "发货数量")
	private BigDecimal sendCount;

	@DocField(value = "到货数量             供应商到货登记时预留字段")
	private BigDecimal arriveCount;

	@DocField(value = "拒收数量")
	private BigDecimal refuseCount;

	@DocField(value = "退货数量")
	private BigDecimal returnCount;

	@DocField(value = "验收数量")
	private BigDecimal inspCount;

	@DocField(value = "售后在途数量")
	private BigDecimal afterServingCount;

	@DocField(value = "异常变更在途数量")
	private BigDecimal chngingCount;

	@DocField(value = "创建时间")
	private Date createTime;

	@DocField(value = "创建时间 开始")
	private Date createTimeStart;

	@DocField(value = "创建时间 结束")
	private Date createTimeEnd;

	@DocField(value = "创建工号")
	private String createOperId;

	@DocField(value = "更新时间")
	private Date updateTime;

	@DocField(value = "更新时间 开始")
	private Date updateTimeStart;

	@DocField(value = "更新时间 结束")
	private Date updateTimeEnd;

	@DocField(value = "更新工号")
	private String updateOperId;

	@DocField(value = "备注")
	private String remark;

	@DocField(value = "删除标志1已删除")
	private Integer delTag;

	@DocField(value = "扩展字段")
	private String extField1;

	@DocField(value = "扩展字段")
	private String extField2;

	@DocField(value = "扩展字段")
	private String extField3;

	@DocField(value = "扩展字段")
	private String extField4;

	@DocField(value = "扩展字段")
	private String extField5;

	@DocField(value = "排序")
	private String orderBy;

	@DocField(value = "发货单IDList")
	private List<Long> shipOrderIdList;

	@DocField(value = "发货单明细IDList")
	private List<Long> shipOrderItemIdList;

	@DocField(value = "订单IDList")
	private List<Long> orderIdList;

	@DocField(value = "销售单明细IDList")
	private List<Long> saleOrderItemIdList;
}

==> order-center-infrastructure-3.2.3-CLOUD-DEV-20241125.101543-26-sources.jar: com/tydic/dyc/oc/repository/po/UocShipOrderItemPo.java <==
package com.tydic.dyc.oc.repository.po;


import lombok.Data;
import lombok.EqualsAndHashCode;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 标题:UocShipOrderItemPo
 * 说明:发货明细
 * 时间:2022-05-13 13:45
 * 作者:罗有
 **/
@Data
@EqualsAndHashCode(callSuper=false)
public class UocShipOrderItemPo implements Serializable {
	private static final long serialVersionUID = -5105669703283919805L;

	//发货明细id")
	private Long shipOrderItemId;

	//订单id")
	private Long orderId;

	//销售单id")
	private Long saleOrderId;

	//销售明细id")
	private Long saleOrderItemId;

	//发货单id")
	private Long shipOrderId;

	//明细状态")
	private String shipItemState;

	//计量单位")
	private String unitName;

	//发货数量")
	private BigDecimal sendCount;

	//到货数量             供应商到货登记时预留字段")
	private BigDecimal arriveCount;

	//拒收数量")
	private BigDecimal refuseCount;

	//退货数量")
	private BigDecimal returnCount;

	//验收数量")
	private BigDecimal inspCount;

	//售后在途数量")
	private BigDecimal afterServingCount;

	//异常变更在途数量")
	private BigDecimal chngingCount;

	//创建时间")
	private Date createTime;

	//创建时间 开始")
	private Date createTimeStart;

	//创建时间 结束")
	private Date createTimeEnd;

	//创建工号")
	private String createOperId;

	//更新时间")
	private Date updateTime;

	//更新时间 开始")
	private Date updateTimeStart;

	//更新时间 结束")
	private Date updateTimeEnd;

	//更新工号")
	private String updateOperId;

	//备注")
	private String remark;

	//删除标志1已删除")
	private Integer delTag;

	//扩展字段")
	private String extField1;

	//扩展字段")
	private String extField2;

	//扩展字段")
	private String extField3;

	//扩展字段")
	private String extField4;

	//扩展字段")
	private String extField5;

	//排序")
	private String orderBy;

	//发货单IDList")
	private List<Long> shipOrderIdList;

	//发货单明细IDList")
	private List<Long> shipOrderItemIdList;

	//订单IDList")
	private List<Long> orderIdList;

	//销售单明细IDList")
	private List<Long> saleOrderItemIdList;
	 //@DocField(value = "归档表后缀")
	private String dataAchiveTabSuffix;

	/**
	 * 已退货明细销售金额
	 */
	private BigDecimal retrunSendSaleFee;

	/**
	 * 已退货明细采购金额
	 */
	private BigDecimal retrunSendPurchaseFee;

	/**
	 * 发货明细销售金额
	 */
	private BigDecimal sendSaleFee;

	/**
	 * 发货明细采购金额
	 */
	private BigDecimal sendPurchaseFee;
}
